.. image:: https://travis-ci.org/SpazioDati/python-dandelion-eu.png?branch=develop
  :target: https://travis-ci.org/SpazioDati/python-dandelion-eu

.. image:: https://coveralls.io/repos/SpazioDati/python-dandelion-eu/badge.png?branch=develop
  :target: https://coveralls.io/r/SpazioDati/python-dandelion-eu?branch=develop

..
    image:: https://pypip.in/v/dandelion-eu/badge.png
    :target: https://crate.io/packages/dandelion-eu/
    :alt: Latest PyPI version

..
    image:: https://pypip.in/d/dandelion-eu/badge.png
    :target: https://crate.io/packages/dandelion-eu/
    :alt: Number of PyPI downloads

.. _PyPI: https://pypi.python.org/pypi/dandelion-eu/
.. _ReadTheDocs: http://python-dandelion-eu.readthedocs.org/


python-dandelion-eu
===================

Connect to the dandelion.eu API in a very pythonic way!


Installation
------------

``dandelion-eu`` is available on PyPI_ install it simply with::

    pip install dandelion-eu


Documentation
-------------

Documentation is available on ReadTheDocs_.
